Class: StackOne::Models::Operations::Status Deprecated

Inherits:
T::Enum
  • Object
show all
Defined in:
lib/stack_one/models/operations/status.rb

Overview

Deprecated.

class: This will be removed in a future release, please migrate away from it as soon as possible.

Status - The status of the job