Class: StackOne::Models::Shared::CostCenter Deprecated
- Inherits:
-
Object
- Object
- StackOne::Models::Shared::CostCenter
- Extended by:
- T::Sig
- Includes:
- Crystalline::MetadataFields
- Defined in:
- lib/stack_one/models/shared/cost_center.rb
Overview
Deprecated.
class: This will be removed in a future release, please migrate away from it as soon as possible.
The employee cost_center
Instance Method Summary collapse
- #==(other) ⇒ Object
-
#initialize(company_id: nil, id: nil, name: nil, owner_ids: nil, parent_ids: nil, remote_company_id: nil, remote_id: nil, remote_owner_ids: nil, remote_parent_ids: nil, type: nil, unified_custom_fields: nil) ⇒ CostCenter
constructor
A new instance of CostCenter.
Methods included from Crystalline::MetadataFields
#field, #fields, included, #marshal_single, #to_dict, #to_json
Constructor Details
#initialize(company_id: nil, id: nil, name: nil, owner_ids: nil, parent_ids: nil, remote_company_id: nil, remote_id: nil, remote_owner_ids: nil, remote_parent_ids: nil, type: nil, unified_custom_fields: nil) ⇒ CostCenter
Returns a new instance of CostCenter.
41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/stack_one/models/shared/cost_center.rb', line 41 def initialize(company_id: nil, id: nil, name: nil, owner_ids: nil, parent_ids: nil, remote_company_id: nil, remote_id: nil, remote_owner_ids: nil, remote_parent_ids: nil, type: nil, unified_custom_fields: nil) @company_id = company_id @id = id @name = name @owner_ids = owner_ids @parent_ids = parent_ids @remote_company_id = remote_company_id @remote_id = remote_id @remote_owner_ids = remote_owner_ids @remote_parent_ids = remote_parent_ids @type = type @unified_custom_fields = unified_custom_fields end |
Instance Method Details
#==(other) ⇒ Object
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/stack_one/models/shared/cost_center.rb', line 56 def ==(other) return false unless other.is_a? self.class return false unless @company_id == other.company_id return false unless @id == other.id return false unless @name == other.name return false unless @owner_ids == other.owner_ids return false unless @parent_ids == other.parent_ids return false unless @remote_company_id == other.remote_company_id return false unless @remote_id == other.remote_id return false unless @remote_owner_ids == other.remote_owner_ids return false unless @remote_parent_ids == other.remote_parent_ids return false unless @type == other.type return false unless @unified_custom_fields == other.unified_custom_fields true end |