Class: StackOne::Models::Shared::HrisDocumentApiModelType Deprecated
- Inherits:
-
Object
- Object
- StackOne::Models::Shared::HrisDocumentApiModelType
- Extended by:
- T::Sig
- Includes:
- Crystalline::MetadataFields
- Defined in:
- lib/stack_one/models/shared/hrisdocumentapimodel_type.rb
Overview
Deprecated.
class: This will be removed in a future release, please migrate away from it as soon as possible.
The content type of the document
Instance Method Summary collapse
- #==(other) ⇒ Object
-
#initialize(source_value: nil, value: nil) ⇒ HrisDocumentApiModelType
constructor
A new instance of HrisDocumentApiModelType.
Methods included from Crystalline::MetadataFields
#field, #fields, included, #marshal_single, #to_dict, #to_json
Constructor Details
#initialize(source_value: nil, value: nil) ⇒ HrisDocumentApiModelType
Returns a new instance of HrisDocumentApiModelType.
23 24 25 26 |
# File 'lib/stack_one/models/shared/hrisdocumentapimodel_type.rb', line 23 def initialize(source_value: nil, value: nil) @source_value = source_value @value = value end |
Instance Method Details
#==(other) ⇒ Object
29 30 31 32 33 34 |
# File 'lib/stack_one/models/shared/hrisdocumentapimodel_type.rb', line 29 def ==(other) return false unless other.is_a? self.class return false unless @source_value == other.source_value return false unless @value == other.value true end |