Class: StackOne::Models::Shared::IamUserAvatar
- Inherits:
-
Object
- Object
- StackOne::Models::Shared::IamUserAvatar
- Extended by:
- T::Sig
- Includes:
- Crystalline::MetadataFields
- Defined in:
- lib/stack_one/models/shared/iamuser_avatar.rb
Overview
The user's avatar data. This generally contains a URL within this property's 'contents' array. May be either a single File object or an array of File objects depending on the connector — both forms are supported.
Instance Method Summary collapse
- #==(other) ⇒ Object
-
#initialize ⇒ IamUserAvatar
constructor
A new instance of IamUserAvatar.
Methods included from Crystalline::MetadataFields
#field, #fields, included, #marshal_single, #to_dict, #to_json
Constructor Details
#initialize ⇒ IamUserAvatar
Returns a new instance of IamUserAvatar.
17 |
# File 'lib/stack_one/models/shared/iamuser_avatar.rb', line 17 def initialize; end |
Instance Method Details
#==(other) ⇒ Object
20 21 22 23 |
# File 'lib/stack_one/models/shared/iamuser_avatar.rb', line 20 def ==(other) return false unless other.is_a? self.class true end |