Class: StackOne::Models::Shared::JobDescription Deprecated
- Inherits:
-
Object
- Object
- StackOne::Models::Shared::JobDescription
- Extended by:
- T::Sig
- Includes:
- Crystalline::MetadataFields
- Defined in:
- lib/stack_one/models/shared/job_description.rb
Overview
Deprecated.
class: This will be removed in a future release, please migrate away from it as soon as possible.
The employee job description
Instance Method Summary collapse
- #==(other) ⇒ Object
-
#initialize(text: nil) ⇒ JobDescription
constructor
A new instance of JobDescription.
Methods included from Crystalline::MetadataFields
#field, #fields, included, #marshal_single, #to_dict, #to_json
Constructor Details
#initialize(text: nil) ⇒ JobDescription
Returns a new instance of JobDescription.
21 22 23 |
# File 'lib/stack_one/models/shared/job_description.rb', line 21 def initialize(text: nil) @text = text end |
Instance Method Details
#==(other) ⇒ Object
26 27 28 29 30 |
# File 'lib/stack_one/models/shared/job_description.rb', line 26 def ==(other) return false unless other.is_a? self.class return false unless @text == other.text true end |