Class: StackOne::Models::Shared::LmsUpsertContentRequestDtoSourceValue
- Inherits:
-
Object
- Object
- StackOne::Models::Shared::LmsUpsertContentRequestDtoSourceValue
- Extended by:
- T::Sig
- Includes:
- Crystalline::MetadataFields
- Defined in:
- lib/stack_one/models/shared/lmsupsertcontentrequestdto_source_value.rb
Overview
The provider-specific value to use when value is omitted or set to “unmapped_value”. You are responsible for ensuring this matches the provider’s expected format.
Instance Method Summary collapse
- #==(other) ⇒ Object
-
#initialize ⇒ LmsUpsertContentRequestDtoSourceValue
constructor
A new instance of LmsUpsertContentRequestDtoSourceValue.
Methods included from Crystalline::MetadataFields
#field, #fields, included, #marshal_single, #to_dict, #to_json
Constructor Details
#initialize ⇒ LmsUpsertContentRequestDtoSourceValue
Returns a new instance of LmsUpsertContentRequestDtoSourceValue.
17 |
# File 'lib/stack_one/models/shared/lmsupsertcontentrequestdto_source_value.rb', line 17 def initialize; end |
Instance Method Details
#==(other) ⇒ Object
20 21 22 23 |
# File 'lib/stack_one/models/shared/lmsupsertcontentrequestdto_source_value.rb', line 20 def ==(other) return false unless other.is_a? self.class true end |