Class: StackOne::Models::Shared::NationalIdentityNumber Deprecated

Inherits:
Object
  • Object
show all
Extended by:
T::Sig
Includes:
Crystalline::MetadataFields
Defined in:
lib/stack_one/models/shared/national_identity_number.rb

Overview

Deprecated.

class: This will be removed in a future release, please migrate away from it as soon as possible.

The national identity number

Instance Method Summary collapse

Methods included from Crystalline::MetadataFields

#field, #fields, included, #marshal_single, #to_dict, #to_json

Constructor Details

#initialize(country: nil, type: nil, value: nil) ⇒ NationalIdentityNumber

Returns a new instance of NationalIdentityNumber.



25
26
27
28
29
# File 'lib/stack_one/models/shared/national_identity_number.rb', line 25

def initialize(country: nil, type: nil, value: nil)
  @country = country
  @type = type
  @value = value
end

Instance Method Details

#==(other) ⇒ Object



32
33
34
35
36
37
38
# File 'lib/stack_one/models/shared/national_identity_number.rb', line 32

def ==(other)
  return false unless other.is_a? self.class
  return false unless @country == other.country
  return false unless @type == other.type
  return false unless @value == other.value
  true
end