Class: StackOne::Models::Shared::TaskValue

Inherits:
Object
  • Object
show all
Includes:
Crystalline::Enum
Defined in:
lib/stack_one/models/shared/task_value.rb

Overview

TaskValue - The unified value for the status of the task. If the provider does not specify this status, the value will be set to UnmappedValue

Method Summary

Methods included from Crystalline::Enum

#==, #eql?, #hash, included, #initialize, #inspect, #known?, #serialize, #to_s