Class: StackOne::Models::Shared::TimeOffBalancesSchemasPolicyValue
- Inherits:
-
Object
- Object
- StackOne::Models::Shared::TimeOffBalancesSchemasPolicyValue
- Includes:
- Crystalline::Enum
- Defined in:
- lib/stack_one/models/shared/timeoffbalances_schemas_policy_value.rb
Overview
TimeOffBalancesSchemasPolicyValue - The unified value for the type of the time off policy. If the provider does not specify this unit, the value will be set to unmapped_value
Method Summary
Methods included from Crystalline::Enum
#==, #eql?, #hash, included, #initialize, #inspect, #known?, #serialize, #to_s