Class: StackOne::Models::Shared::TimeOffPoliciesSchemasValue

Inherits:
Object
  • Object
show all
Includes:
Crystalline::Enum
Defined in:
lib/stack_one/models/shared/timeoffpolicies_schemas_value.rb

Overview

TimeOffPoliciesSchemasValue - The unified value for the type of the time off policy. If the provider does not specify this unit, the value will be set to unmapped_value

Method Summary

Methods included from Crystalline::Enum

#==, #eql?, #hash, included, #initialize, #inspect, #known?, #serialize, #to_s