Class: StackOne::Models::Shared::UpdateTaskRequestDtoValue
- Inherits:
-
Object
- Object
- StackOne::Models::Shared::UpdateTaskRequestDtoValue
- Includes:
- Crystalline::Enum
- Defined in:
- lib/stack_one/models/shared/updatetaskrequestdto_value.rb
Overview
UpdateTaskRequestDtoValue - The unified value for the status of the task. If the provider does not specify this status, the value will be set to UnmappedValue
Method Summary
Methods included from Crystalline::Enum
#==, #eql?, #hash, included, #initialize, #inspect, #known?, #serialize, #to_s