Class: StackOne::Models::Shared::IamMfaTypeEnumValue
- Inherits:
-
Object
- Object
- StackOne::Models::Shared::IamMfaTypeEnumValue
- Includes:
- Crystalline::Enum
- Defined in:
- lib/stack_one/models/shared/iammfatypeenum_value.rb
Overview
IamMfaTypeEnumValue - The unified value for the type of multi-factor authentication. If the provider does not send back a type but does specify that MFA is set-up for this user, the value will be set to ‘unknown’.‘
Method Summary
Methods included from Crystalline::Enum
#==, #eql?, #hash, included, #initialize, #inspect, #known?, #serialize, #to_s